| Title: | Functions for Elementary Bayesian Inference |
|---|---|
| Description: | A set of R functions and data sets for the book Introduction to Bayesian Statistics, Bolstad, W.M. (2017), John Wiley & Sons ISBN 978-1-118-09156-2. |
| Authors: | James Curran [aut, cre] (Original author) |
| Maintainer: | James Curran <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.2.42 |
| Built: | 2026-06-08 09:30:33 UTC |
| Source: | https://github.com/jmcurran/bolstad |